window.Gleam.initSearch([{"doc":"kirala_l4u","title":"kirala_l4u","content":"# Kirala L4u(Lisp for You) for Gleam language ver 1.0.0\n- Kirara is Japanese for &quot;gleam&quot; feeling word in English.\n\nL4u is a embedded lisp interpreter dialect of MAL for use in gleam/erlang and gleam/javascript products.\n\n\nThis is still under construction and may undergo destructive changes.\nIt is intended to work with both gleam/erlang and gleam/javascript.\nCurrently it is only confirmed to work with erlang. The javascript version is in the works because gleam javascript is no longer working in my current Gleam environment.\n\nIt is roughly compatible with MAL (Make A Lisp).\nAlthough this is a different implementation from the standard MAL method, it should be lisp compatible, so the following page should be helpful.\nhttps://github.com/kanaka/mal\n\nIt is a very techy rough performance evaluation,\nIn the benchmark (tarai 12 6 0), I compared it with MAL&#39;s impls/c,erlang,elixir,python,ruby,\n- c unable to complete due to segmentation fault\n- erlang failed to complete(too many procecces)\n- elixir failed to complete(too many procecces)\n- 7 to 15 times faster than python\n- 2 to 4 times faster than ruby  \nI think this implementation is not so bad.\n\n## build\n```\n./prepare.sh\n\n# erlang target\n./set-host-language.sh --erl\n\n# javascript target \n./set-host-language.sh --js\n```\n\n\n## embedding sample\n\nsrc/examples/test_l4u.gleam\n```\nimport l4u/l4u\nimport gleam/list\nimport gleam/dict.{Dict}\nimport gleam/string\nimport l4u/l4u_core.{\n  BIF, BISPFORM, Env, Expr, STRING, WithEnv, description, pstr,\n}\n\nfn bif_hello(exprs: List(Expr), env: Env) -&gt; Expr {\n  let names =\n    list.map(exprs, fn(e) { pstr(e) })\n    |&gt; string.join(&quot;, &quot;)\n  let message = &quot;Hello, &quot; &lt;&gt; names &lt;&gt; &quot;!!&quot;\n  WithEnv(STRING(message), env)\n}\n\nfn bsf_hello_special_form(exprs: List(Expr), env: Env) -&gt; Expr {\n  let names =\n    list.map(exprs, fn(e) { pstr(e) })\n    |&gt; string.join(&quot;, &quot;)\n  let message = &quot;Hello, &quot; &lt;&gt; names &lt;&gt; &quot;!!&quot;\n  WithEnv(STRING(message), env)\n}\n\npub fn main() {\n  let bif = fn(name, f) { #(name, BIF(description(name), f)) }\n  let bsf = fn(name, f) { #(name, BISPFORM(description(name), f)) }\n  let defs = [\n    bif(&quot;hello_fn&quot;, bif_hello),\n    bsf(&quot;hello_special_form&quot;, bsf_hello_special_form),\n  ]\n\n  let l4uobj = l4u.start_and_generate_main_l4u(defs)\n  l4u.repl(l4uobj, &quot;l4u&gt; &quot;)\n}\n\n```\n\n```\n$ gleam shell\nErlang/OTP 26 [erts-14.0.2] [source] [64-bit] [smp:8:8] [ds:8:8:10] [async-threads:1] [jit] [dtrace]\n\nEshell V14.0.2 (press Ctrl+G to abort, type help(). for help)\n1&gt; examples@l4u@test_l4u:main().\nCreating qdate ETS Table: qdate_srv\n- init default0.lisp\n- init default1.lisp\n- init prelude.lisp\n|0.87.0|main|l4u&gt; (hello_fn &quot;alpha&quot; :beta &#39;gamma (+ 10 20))\n&quot;Hello, alpha, beta, gamma, 30!!&quot;\n|0.87.0|main|l4u&gt; (hello_special_form &quot;alpha&quot; :beta &#39;gamma (+ 10 20))\n&quot;Hello, alpha, beta, quote gamma, + 10 20!!&quot;\n```\n\n## import and call native module/functions\n\n```\n; (import-native-module MODULE_NAME ALIAS)\n; All of the following will work the same.\n(import-native-module [:examples :l4u :test_l4u] :test-l4u)\n; (import-native-module &#39;[examples l4u test_l4u] :test-l4u)\n; (import-native-module &#39;[examples@l4u@test_l4u] :test-l4u)\n\n; (global-keys) retrieves the keys of all variables bound to the global region. It is also possible to filter by forward matching strings as follows\n(global-keys :test)\n\n; Call the function and start the REPL the same way you did in erlang.\n(test_l4u:main)\n```","url":"index.html"},{"doc":"l4u/l4u_type","title":"Description","content":"pub type Description {\n  Description(name: String, text: String)\n}\n\nDescription(name: String, text: String)\n\n\nSynonyms:\nl4u/l4u_type.Description\nl4u/l4u_type Description","url":"l4u/l4u_type.html#Description"},{"doc":"l4u/l4u_type","title":"Env","content":"pub type Env {\n  Env(\n    info: Info,\n    pdic: PDic,\n    local_vars: Dict(String, Expr),\n    a_binding: Dict(String, Expr),\n    scopes: List(Scope),\n    opts: EnvOptions,\n  )\n}\n\nEnv(\n  info: Info,\n  pdic: PDic,\n  local_vars: Dict(String, Expr),\n  a_binding: Dict(String, Expr),\n  scopes: List(Scope),\n  opts: EnvOptions,\n)\n\n\nSynonyms:\nl4u/l4u_type.Env\nl4u/l4u_type Env","url":"l4u/l4u_type.html#Env"},{"doc":"l4u/l4u_type","title":"EnvOption","content":"pub type EnvOption {\n  VERBOSE\n  TRACE\n}\n\nVERBOSE\n\n\nTRACE\n\n\nSynonyms:\nl4u/l4u_type.EnvOption\nl4u/l4u_type EnvOption","url":"l4u/l4u_type.html#EnvOption"},{"doc":"l4u/l4u_type","title":"EnvOptions","content":"pub type EnvOptions {\n  EnvOptions(verbose: Bool, trace: Bool)\n}\n\nEnvOptions(verbose: Bool, trace: Bool)\n\n\nSynonyms:\nl4u/l4u_type.EnvOptions\nl4u/l4u_type EnvOptions","url":"l4u/l4u_type.html#EnvOptions"},{"doc":"l4u/l4u_type","title":"ErrorEx","content":"pub type ErrorEx {\n  ErrorEx2(msg: String, detail: Dynamic)\n}\n\nErrorEx2(msg: String, detail: Dynamic)\n\n\nSynonyms:\nl4u/l4u_type.ErrorEx\nl4u/l4u_type ErrorEx","url":"l4u/l4u_type.html#ErrorEx"},{"doc":"l4u/l4u_type","title":"Expr","content":"pub type Expr {\n  PRINTABLE(Expr)\n  UNDEFINED\n  NIL\n  TRUE\n  FALSE\n  DELIMITER\n  WithEnv(Expr, Env)\n  LocalContinuation(List(Expr), Env, Env)\n  Continuation(List(Expr), Env)\n  ATOM(Ref)\n  INT(Int)\n  FLOAT(Float)\n  STRING(String)\n  SYMBOL(String)\n  ExVAR(String, String)\n  KEYWORD(String)\n  LIST(List(Expr))\n  VECTOR(List(Expr))\n  DICT(List(Expr))\n  BIF(Description, fn(List(Expr), Env) -&gt; Expr)\n  BISPFORM(Description, fn(List(Expr), Env) -&gt; Expr)\n  CLOSURE(Description, List(String), List(Expr), Env)\n  MACRO(Description, List(String), List(Expr), Env)\n  WithMeta(Expr, Expr)\n  NativeValue(String, Dynamic)\n  NativeFunction(String, Dynamic)\n  ReplCommand(String, Expr)\n  CustomType(String, Expr)\n  CustomTypeDef(String, Expr)\n}\n\nPRINTABLE(Expr)\n\n\nUNDEFINED\n\n\nNIL\n\n\nTRUE\n\n\nFALSE\n\n\nDELIMITER\n\n\nWithEnv(Expr, Env)\n\n\nLocalContinuation(List(Expr), Env, Env)\n\n\nContinuation(List(Expr), Env)\n\n\nATOM(Ref)\n\n\nINT(Int)\n\n\nFLOAT(Float)\n\n\nSTRING(String)\n\n\nSYMBOL(String)\n\n\nExVAR(String, String)\n\n\nKEYWORD(String)\n\n\nLIST(List(Expr))\n\n\nVECTOR(List(Expr))\n\n\nDICT(List(Expr))\n\n\nBIF(Description, fn(List(Expr), Env) -&gt; Expr)\n\n\nBISPFORM(Description, fn(List(Expr), Env) -&gt; Expr)\n\n\nCLOSURE(Description, List(String), List(Expr), Env)\n\n\nMACRO(Description, List(String), List(Expr), Env)\n\n\nWithMeta(Expr, Expr)\n\n\nNativeValue(String, Dynamic)\n\n\nNativeFunction(String, Dynamic)\n\n\nReplCommand(String, Expr)\n\n\nCustomType(String, Expr)\n\n\nCustomTypeDef(String, Expr)\n\n\nSynonyms:\nl4u/l4u_type.Expr\nl4u/l4u_type Expr","url":"l4u/l4u_type.html#Expr"},{"doc":"l4u/l4u_type","title":"Info","content":"pub type Info {\n  Info(name: String, level: Int)\n}\n\nInfo(name: String, level: Int)\n\n\nSynonyms:\nl4u/l4u_type.Info\nl4u/l4u_type Info","url":"l4u/l4u_type.html#Info"},{"doc":"l4u/l4u_type","title":"PDic","content":"pub type PDic\n\n\nSynonyms:\nl4u/l4u_type.PDic\nl4u/l4u_type PDic","url":"l4u/l4u_type.html#PDic"},{"doc":"l4u/l4u_type","title":"Ref","content":"pub type Ref\n\n\nSynonyms:\nl4u/l4u_type.Ref\nl4u/l4u_type Ref","url":"l4u/l4u_type.html#Ref"},{"doc":"l4u/l4u_type","title":"Scope","content":"pub type Scope {\n  Scope(bindings: Dict(String, Expr))\n  ProcessDict(PDic)\n}\n\nScope(bindings: Dict(String, Expr))\n\n\nProcessDict(PDic)\n\n\nSynonyms:\nl4u/l4u_type.Scope\nl4u/l4u_type Scope","url":"l4u/l4u_type.html#Scope"},{"doc":"l4u/l4u_type","title":"box_l4u_custom_type","content":"pub fn box_l4u_custom_type(name: String, x: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_custom_type\nl4u/l4u_type box_l4u_custom_type","url":"l4u/l4u_type.html#box_l4u_custom_type"},{"doc":"l4u/l4u_type","title":"box_l4u_custom_type_def","content":"pub fn box_l4u_custom_type_def(name: String, x: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_custom_type_def\nl4u/l4u_type box_l4u_custom_type_def","url":"l4u/l4u_type.html#box_l4u_custom_type_def"},{"doc":"l4u/l4u_type","title":"box_l4u_dict","content":"pub fn box_l4u_dict(x: List(Expr)) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_dict\nl4u/l4u_type box_l4u_dict","url":"l4u/l4u_type.html#box_l4u_dict"},{"doc":"l4u/l4u_type","title":"box_l4u_float","content":"pub fn box_l4u_float(x: Float) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_float\nl4u/l4u_type box_l4u_float","url":"l4u/l4u_type.html#box_l4u_float"},{"doc":"l4u/l4u_type","title":"box_l4u_int","content":"pub fn box_l4u_int(x: Int) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_int\nl4u/l4u_type box_l4u_int","url":"l4u/l4u_type.html#box_l4u_int"},{"doc":"l4u/l4u_type","title":"box_l4u_keyword","content":"pub fn box_l4u_keyword(x: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_keyword\nl4u/l4u_type box_l4u_keyword","url":"l4u/l4u_type.html#box_l4u_keyword"},{"doc":"l4u/l4u_type","title":"box_l4u_list","content":"pub fn box_l4u_list(x: List(Expr)) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_list\nl4u/l4u_type box_l4u_list","url":"l4u/l4u_type.html#box_l4u_list"},{"doc":"l4u/l4u_type","title":"box_l4u_native_function","content":"pub fn box_l4u_native_function(name: String, x: Dynamic) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_native_function\nl4u/l4u_type box_l4u_native_function","url":"l4u/l4u_type.html#box_l4u_native_function"},{"doc":"l4u/l4u_type","title":"box_l4u_native_value","content":"pub fn box_l4u_native_value(name: String, x: Dynamic) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_native_value\nl4u/l4u_type box_l4u_native_value","url":"l4u/l4u_type.html#box_l4u_native_value"},{"doc":"l4u/l4u_type","title":"box_l4u_ok","content":"pub fn box_l4u_ok(x: a) -&gt; Result(a, b)\n\nSynonyms:\nl4u/l4u_type.box_l4u_ok\nl4u/l4u_type box_l4u_ok","url":"l4u/l4u_type.html#box_l4u_ok"},{"doc":"l4u/l4u_type","title":"box_l4u_string","content":"pub fn box_l4u_string(x: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_string\nl4u/l4u_type box_l4u_string","url":"l4u/l4u_type.html#box_l4u_string"},{"doc":"l4u/l4u_type","title":"box_l4u_symbol","content":"pub fn box_l4u_symbol(x: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_symbol\nl4u/l4u_type box_l4u_symbol","url":"l4u/l4u_type.html#box_l4u_symbol"},{"doc":"l4u/l4u_type","title":"box_l4u_vector","content":"pub fn box_l4u_vector(x: List(Expr)) -&gt; Expr\n\nSynonyms:\nl4u/l4u_type.box_l4u_vector\nl4u/l4u_type box_l4u_vector","url":"l4u/l4u_type.html#box_l4u_vector"},{"doc":"l4u/l4u_type","title":"native_false","content":"pub fn native_false() -&gt; a\n\nSynonyms:\nl4u/l4u_type.native_false\nl4u/l4u_type native_false","url":"l4u/l4u_type.html#native_false"},{"doc":"l4u/l4u_type","title":"native_nil","content":"pub fn native_nil() -&gt; a\n\nSynonyms:\nl4u/l4u_type.native_nil\nl4u/l4u_type native_nil","url":"l4u/l4u_type.html#native_nil"},{"doc":"l4u/l4u_type","title":"native_true","content":"pub fn native_true() -&gt; a\n\nSynonyms:\nl4u/l4u_type.native_true\nl4u/l4u_type native_true","url":"l4u/l4u_type.html#native_true"},{"doc":"l4u/l4u_type","title":"native_undefined","content":"pub fn native_undefined() -&gt; a\n\nSynonyms:\nl4u/l4u_type.native_undefined\nl4u/l4u_type native_undefined","url":"l4u/l4u_type.html#native_undefined"},{"doc":"l4u/l4u_type","title":"to_native_dictionary","content":"pub fn to_native_dictionary(xs: List(a)) -&gt; b\n\nSynonyms:\nl4u/l4u_type.to_native_dictionary\nl4u/l4u_type to_native_dictionary","url":"l4u/l4u_type.html#to_native_dictionary"},{"doc":"l4u/l4u_type","title":"unbox_l4u","content":"pub fn unbox_l4u(expr: Expr) -&gt; a\n\nSynonyms:\nl4u/l4u_type.unbox_l4u\nl4u/l4u_type unbox_l4u","url":"l4u/l4u_type.html#unbox_l4u"},{"doc":"l4u/l4u_type","title":"unsafe_corece","content":"pub fn unsafe_corece(value: a) -&gt; b\n\nSynonyms:\nl4u/l4u_type.unsafe_corece\nl4u/l4u_type unsafe_corece","url":"l4u/l4u_type.html#unsafe_corece"},{"doc":"l4u/l4u_type","title":"l4u/l4u_type","content":"let assert [Scope(tvars), ..] = closure_env.scopes","url":"l4u/l4u_type.html"},{"doc":"l4u/sys_bridge","title":"ErlSym","content":"pub type ErlSym\n\n\nSynonyms:\nl4u/sys_bridge.ErlSym\nl4u/sys_bridge ErlSym","url":"l4u/sys_bridge.html#ErlSym"},{"doc":"l4u/sys_bridge","title":"Pid","content":"pub type Pid\n\n\nSynonyms:\nl4u/sys_bridge.Pid\nl4u/sys_bridge Pid","url":"l4u/sys_bridge.html#Pid"},{"doc":"l4u/sys_bridge","title":"abspath","content":"pub fn abspath(path: String) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.abspath\nl4u/sys_bridge abspath","url":"l4u/sys_bridge.html#abspath"},{"doc":"l4u/sys_bridge","title":"aux_pdic","content":"pub fn aux_pdic(pdic: PDic, id: String) -&gt; PDic\n\nSynonyms:\nl4u/sys_bridge.aux_pdic\nl4u/sys_bridge aux_pdic","url":"l4u/sys_bridge.html#aux_pdic"},{"doc":"l4u/sys_bridge","title":"catch_dummy","content":"pub fn catch_dummy(try_fn: fn() -&gt; a) -&gt; Result(a, b)\n\nSynonyms:\nl4u/sys_bridge.catch_dummy\nl4u/sys_bridge catch_dummy","url":"l4u/sys_bridge.html#catch_dummy"},{"doc":"l4u/sys_bridge","title":"catch_ex","content":"pub fn catch_ex(try_fn: fn() -&gt; a) -&gt; Result(a, b)\n\nSynonyms:\nl4u/sys_bridge.catch_ex\nl4u/sys_bridge catch_ex","url":"l4u/sys_bridge.html#catch_ex"},{"doc":"l4u/sys_bridge","title":"compare_any","content":"pub fn compare_any(x: Expr, y: Expr) -&gt; Order\n\nSynonyms:\nl4u/sys_bridge.compare_any\nl4u/sys_bridge compare_any","url":"l4u/sys_bridge.html#compare_any"},{"doc":"l4u/sys_bridge","title":"console_readline","content":"pub fn console_readline(prompt: String) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.console_readline\nl4u/sys_bridge console_readline","url":"l4u/sys_bridge.html#console_readline"},{"doc":"l4u/sys_bridge","title":"console_writeln","content":"pub fn console_writeln(s: a) -&gt; Nil\n\nSynonyms:\nl4u/sys_bridge.console_writeln\nl4u/sys_bridge console_writeln","url":"l4u/sys_bridge.html#console_writeln"},{"doc":"l4u/sys_bridge","title":"dbgout1","content":"pub fn dbgout1(a: a) -&gt; Bool\n\nSynonyms:\nl4u/sys_bridge.dbgout1\nl4u/sys_bridge dbgout1","url":"l4u/sys_bridge.html#dbgout1"},{"doc":"l4u/sys_bridge","title":"dbgout2","content":"pub fn dbgout2(a: a, b: b) -&gt; Bool\n\nSynonyms:\nl4u/sys_bridge.dbgout2\nl4u/sys_bridge dbgout2","url":"l4u/sys_bridge.html#dbgout2"},{"doc":"l4u/sys_bridge","title":"dbgout3","content":"pub fn dbgout3(a: a, b: b, c: c) -&gt; Bool\n\nSynonyms:\nl4u/sys_bridge.dbgout3\nl4u/sys_bridge dbgout3","url":"l4u/sys_bridge.html#dbgout3"},{"doc":"l4u/sys_bridge","title":"dbgout4","content":"pub fn dbgout4(a: a, b: b, c: c, d: d) -&gt; Bool\n\nSynonyms:\nl4u/sys_bridge.dbgout4\nl4u/sys_bridge dbgout4","url":"l4u/sys_bridge.html#dbgout4"},{"doc":"l4u/sys_bridge","title":"deref","content":"pub fn deref(ref: Ref) -&gt; a\n\nSynonyms:\nl4u/sys_bridge.deref\nl4u/sys_bridge deref","url":"l4u/sys_bridge.html#deref"},{"doc":"l4u/sys_bridge","title":"dir_exists","content":"pub fn dir_exists(dir_path: String) -&gt; Bool\n\nSynonyms:\nl4u/sys_bridge.dir_exists\nl4u/sys_bridge dir_exists","url":"l4u/sys_bridge.html#dir_exists"},{"doc":"l4u/sys_bridge","title":"do_async","content":"pub fn do_async(f: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nl4u/sys_bridge.do_async\nl4u/sys_bridge do_async","url":"l4u/sys_bridge.html#do_async"},{"doc":"l4u/sys_bridge","title":"erl_sym","content":"pub fn erl_sym(str: String) -&gt; ErlSym\n\nSynonyms:\nl4u/sys_bridge.erl_sym\nl4u/sys_bridge erl_sym","url":"l4u/sys_bridge.html#erl_sym"},{"doc":"l4u/sys_bridge","title":"error_to_string","content":"pub fn error_to_string(x: a, verbose: Bool) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.error_to_string\nl4u/sys_bridge error_to_string","url":"l4u/sys_bridge.html#error_to_string"},{"doc":"l4u/sys_bridge","title":"escape_binary_string","content":"pub fn escape_binary_string(str: String) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.escape_binary_string\nl4u/sys_bridge escape_binary_string","url":"l4u/sys_bridge.html#escape_binary_string"},{"doc":"l4u/sys_bridge","title":"exec","content":"pub fn exec(pid: Pid, f: fn(a) -&gt; b) -&gt; Result(b, c)\n\nSynonyms:\nl4u/sys_bridge.exec\nl4u/sys_bridge exec","url":"l4u/sys_bridge.html#exec"},{"doc":"l4u/sys_bridge","title":"exec_native","content":"pub fn exec_native(pid: Pid, f: fn(a) -&gt; b) -&gt; Result(b, c)\n\nSynonyms:\nl4u/sys_bridge.exec_native\nl4u/sys_bridge exec_native","url":"l4u/sys_bridge.html#exec_native"},{"doc":"l4u/sys_bridge","title":"external_form","content":"pub fn external_form(value: a) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.external_form\nl4u/sys_bridge external_form","url":"l4u/sys_bridge.html#external_form"},{"doc":"l4u/sys_bridge","title":"file_exists","content":"pub fn file_exists(file_path: String) -&gt; Bool\n\nSynonyms:\nl4u/sys_bridge.file_exists\nl4u/sys_bridge file_exists","url":"l4u/sys_bridge.html#file_exists"},{"doc":"l4u/sys_bridge","title":"get_command_line_args","content":"pub fn get_command_line_args() -&gt; List(String)\n\nSynonyms:\nl4u/sys_bridge.get_command_line_args\nl4u/sys_bridge get_command_line_args","url":"l4u/sys_bridge.html#get_command_line_args"},{"doc":"l4u/sys_bridge","title":"get_cwd","content":"pub fn get_cwd() -&gt; String\n\nSynonyms:\nl4u/sys_bridge.get_cwd\nl4u/sys_bridge get_cwd","url":"l4u/sys_bridge.html#get_cwd"},{"doc":"l4u/sys_bridge","title":"internal_form","content":"pub fn internal_form(value: a) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.internal_form\nl4u/sys_bridge internal_form","url":"l4u/sys_bridge.html#internal_form"},{"doc":"l4u/sys_bridge","title":"l4u_to_native","content":"pub fn l4u_to_native(value: Expr) -&gt; a\n\nSynonyms:\nl4u/sys_bridge.l4u_to_native\nl4u/sys_bridge l4u_to_native","url":"l4u/sys_bridge.html#l4u_to_native"},{"doc":"l4u/sys_bridge","title":"load_file","content":"pub fn load_file(filename: String) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.load_file\nl4u/sys_bridge load_file","url":"l4u/sys_bridge.html#load_file"},{"doc":"l4u/sys_bridge","title":"make_ref","content":"pub fn make_ref(value: a) -&gt; Ref\n\nSynonyms:\nl4u/sys_bridge.make_ref\nl4u/sys_bridge make_ref","url":"l4u/sys_bridge.html#make_ref"},{"doc":"l4u/sys_bridge","title":"native_to_l4u","content":"pub fn native_to_l4u(value: Dynamic) -&gt; a\n\nSynonyms:\nl4u/sys_bridge.native_to_l4u\nl4u/sys_bridge native_to_l4u","url":"l4u/sys_bridge.html#native_to_l4u"},{"doc":"l4u/sys_bridge","title":"new_process","content":"pub fn new_process(initializer: fn() -&gt; a) -&gt; Result(Pid, b)\n\nSynonyms:\nl4u/sys_bridge.new_process\nl4u/sys_bridge new_process","url":"l4u/sys_bridge.html#new_process"},{"doc":"l4u/sys_bridge","title":"os_cmd","content":"pub fn os_cmd(cmdline: String) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.os_cmd\nl4u/sys_bridge os_cmd","url":"l4u/sys_bridge.html#os_cmd"},{"doc":"l4u/sys_bridge","title":"process_dict_erase","content":"pub fn process_dict_erase(pdic: PDic, key: String) -&gt; a\n\nSynonyms:\nl4u/sys_bridge.process_dict_erase\nl4u/sys_bridge process_dict_erase","url":"l4u/sys_bridge.html#process_dict_erase"},{"doc":"l4u/sys_bridge","title":"process_dict_get","content":"pub fn process_dict_get(pdic: PDic, key: String) -&gt; a\n\nSynonyms:\nl4u/sys_bridge.process_dict_get\nl4u/sys_bridge process_dict_get","url":"l4u/sys_bridge.html#process_dict_get"},{"doc":"l4u/sys_bridge","title":"process_dict_keys","content":"pub fn process_dict_keys(pdic: PDic) -&gt; List(String)\n\nSynonyms:\nl4u/sys_bridge.process_dict_keys\nl4u/sys_bridge process_dict_keys","url":"l4u/sys_bridge.html#process_dict_keys"},{"doc":"l4u/sys_bridge","title":"process_dict_set","content":"pub fn process_dict_set(pdic: PDic, key: String, value: a) -&gt; Nil\n\nSynonyms:\nl4u/sys_bridge.process_dict_set\nl4u/sys_bridge process_dict_set","url":"l4u/sys_bridge.html#process_dict_set"},{"doc":"l4u/sys_bridge","title":"reset_ref","content":"pub fn reset_ref(ref: Ref, value: a) -&gt; a\n\nSynonyms:\nl4u/sys_bridge.reset_ref\nl4u/sys_bridge reset_ref","url":"l4u/sys_bridge.html#reset_ref"},{"doc":"l4u/sys_bridge","title":"set_cwd","content":"pub fn set_cwd(dir_path: String) -&gt; Nil\n\nSynonyms:\nl4u/sys_bridge.set_cwd\nl4u/sys_bridge set_cwd","url":"l4u/sys_bridge.html#set_cwd"},{"doc":"l4u/sys_bridge","title":"stringify","content":"pub fn stringify(x: a) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.stringify\nl4u/sys_bridge stringify","url":"l4u/sys_bridge.html#stringify"},{"doc":"l4u/sys_bridge","title":"tco_loop","content":"pub fn tco_loop(f: a, initial_param: b) -&gt; c\n\nSynonyms:\nl4u/sys_bridge.tco_loop\nl4u/sys_bridge tco_loop","url":"l4u/sys_bridge.html#tco_loop"},{"doc":"l4u/sys_bridge","title":"throw_err","content":"pub fn throw_err(s: String) -&gt; Nil\n\nSynonyms:\nl4u/sys_bridge.throw_err\nl4u/sys_bridge throw_err","url":"l4u/sys_bridge.html#throw_err"},{"doc":"l4u/sys_bridge","title":"throw_expr","content":"pub fn throw_expr(expr: a) -&gt; Nil\n\nSynonyms:\nl4u/sys_bridge.throw_expr\nl4u/sys_bridge throw_expr","url":"l4u/sys_bridge.html#throw_expr"},{"doc":"l4u/sys_bridge","title":"tick_count","content":"pub fn tick_count() -&gt; Int\n\nSynonyms:\nl4u/sys_bridge.tick_count\nl4u/sys_bridge tick_count","url":"l4u/sys_bridge.html#tick_count"},{"doc":"l4u/sys_bridge","title":"to_string","content":"pub fn to_string(x: a) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.to_string\nl4u/sys_bridge to_string","url":"l4u/sys_bridge.html#to_string"},{"doc":"l4u/sys_bridge","title":"unescape_binary_string","content":"pub fn unescape_binary_string(str: String) -&gt; String\n\nSynonyms:\nl4u/sys_bridge.unescape_binary_string\nl4u/sys_bridge unescape_binary_string","url":"l4u/sys_bridge.html#unescape_binary_string"},{"doc":"l4u/sys_bridge","title":"unique_int","content":"pub fn unique_int() -&gt; Int\n\nSynonyms:\nl4u/sys_bridge.unique_int\nl4u/sys_bridge unique_int","url":"l4u/sys_bridge.html#unique_int"},{"doc":"l4u/sys_bridge","title":"unique_pdic","content":"pub fn unique_pdic() -&gt; PDic\n\nSynonyms:\nl4u/sys_bridge.unique_pdic\nl4u/sys_bridge unique_pdic","url":"l4u/sys_bridge.html#unique_pdic"},{"doc":"l4u/sys_bridge","title":"unique_str","content":"pub fn unique_str() -&gt; String\n\nSynonyms:\nl4u/sys_bridge.unique_str\nl4u/sys_bridge unique_str","url":"l4u/sys_bridge.html#unique_str"},{"doc":"l4u/sys_bridge","title":"l4u/sys_bridge","content":"","url":"l4u/sys_bridge.html"},{"doc":"l4u/l4u_util","title":"split_multiline_string","content":"pub fn split_multiline_string(src: String) -&gt; List(String)\n\nSynonyms:\nl4u/l4u_util.split_multiline_string\nl4u/l4u_util split_multiline_string","url":"l4u/l4u_util.html#split_multiline_string"},{"doc":"l4u/l4u_util","title":"l4u/l4u_util","content":"","url":"l4u/l4u_util.html"},{"doc":"gleam_bridge","title":"init_gleam_bridge","content":"pub fn init_gleam_bridge() -&gt; Bool\n\nSynonyms:\ngleam_bridge.init_gleam_bridge\ngleam_bridge init_gleam_bridge","url":"gleam_bridge.html#init_gleam_bridge"},{"doc":"gleam_bridge","title":"return_error","content":"pub fn return_error(value: a) -&gt; Result(b, a)\n\nSynonyms:\ngleam_bridge.return_error\ngleam_bridge return_error","url":"gleam_bridge.html#return_error"},{"doc":"gleam_bridge","title":"return_ok","content":"pub fn return_ok(value: a) -&gt; Result(a, b)\n\nSynonyms:\ngleam_bridge.return_ok\ngleam_bridge return_ok","url":"gleam_bridge.html#return_ok"},{"doc":"gleam_bridge","title":"gleam_bridge","content":"","url":"gleam_bridge.html"},{"doc":"l4u/union_term","title":"erase","content":"pub fn erase(key: String) -&gt; Nil\n\nSynonyms:\nl4u/union_term.erase\nl4u/union_term erase","url":"l4u/union_term.html#erase"},{"doc":"l4u/union_term","title":"get","content":"pub fn get(key: String, default_value: a) -&gt; a\n\nSynonyms:\nl4u/union_term.get\nl4u/union_term get","url":"l4u/union_term.html#get"},{"doc":"l4u/union_term","title":"get_int","content":"pub fn get_int(key: String, default_value: Int) -&gt; Int\n\nSynonyms:\nl4u/union_term.get_int\nl4u/union_term get_int","url":"l4u/union_term.html#get_int"},{"doc":"l4u/union_term","title":"get_map","content":"pub fn get_map(key: String) -&gt; Dict(String, a)\n\nSynonyms:\nl4u/union_term.get_map\nl4u/union_term get_map","url":"l4u/union_term.html#get_map"},{"doc":"l4u/union_term","title":"get_map_value","content":"pub fn get_map_value(\n  key: String,\n  property_key: String,\n  default_value: a,\n) -&gt; a\n\nSynonyms:\nl4u/union_term.get_map_value\nl4u/union_term get_map_value","url":"l4u/union_term.html#get_map_value"},{"doc":"l4u/union_term","title":"get_str","content":"pub fn get_str(key: String, default_value: String) -&gt; String\n\nSynonyms:\nl4u/union_term.get_str\nl4u/union_term get_str","url":"l4u/union_term.html#get_str"},{"doc":"l4u/union_term","title":"get_with_default","content":"pub fn get_with_default(a: String, default_value: a) -&gt; a\n\nSynonyms:\nl4u/union_term.get_with_default\nl4u/union_term get_with_default","url":"l4u/union_term.html#get_with_default"},{"doc":"l4u/union_term","title":"keys","content":"pub fn keys() -&gt; List(String)\n\nSynonyms:\nl4u/union_term.keys\nl4u/union_term keys","url":"l4u/union_term.html#keys"},{"doc":"l4u/union_term","title":"nt_get_with_default","content":"pub fn nt_get_with_default(a: a, default_value: b) -&gt; b\n\nSynonyms:\nl4u/union_term.nt_get_with_default\nl4u/union_term nt_get_with_default","url":"l4u/union_term.html#nt_get_with_default"},{"doc":"l4u/union_term","title":"nt_put","content":"pub fn nt_put(key: a, value: b) -&gt; Nil\n\nSynonyms:\nl4u/union_term.nt_put\nl4u/union_term nt_put","url":"l4u/union_term.html#nt_put"},{"doc":"l4u/union_term","title":"put","content":"pub fn put(key: String, value: a) -&gt; Nil\n\nSynonyms:\nl4u/union_term.put\nl4u/union_term put","url":"l4u/union_term.html#put"},{"doc":"l4u/union_term","title":"put_int","content":"pub fn put_int(key: String, value: Int) -&gt; Nil\n\nSynonyms:\nl4u/union_term.put_int\nl4u/union_term put_int","url":"l4u/union_term.html#put_int"},{"doc":"l4u/union_term","title":"put_str","content":"pub fn put_str(key: String, value: String) -&gt; Nil\n\nSynonyms:\nl4u/union_term.put_str\nl4u/union_term put_str","url":"l4u/union_term.html#put_str"},{"doc":"l4u/union_term","title":"set_map_value","content":"pub fn set_map_value(\n  key: String,\n  property_key: String,\n  property_value: Dynamic,\n) -&gt; Nil\n\nSynonyms:\nl4u/union_term.set_map_value\nl4u/union_term set_map_value","url":"l4u/union_term.html#set_map_value"},{"doc":"l4u/union_term","title":"l4u/union_term","content":"","url":"l4u/union_term.html"},{"doc":"l4u/l4u_core","title":"host_language","content":"pub const host_language: Expr = STRING(&quot;gleam-erlang&quot;)\n\nSynonyms:\nl4u/l4u_core.host_language\nl4u/l4u_core host_language","url":"l4u/l4u_core.html#host_language"},{"doc":"l4u/l4u_core","title":"sym_list","content":"pub const sym_list: Expr = SYMBOL(&quot;list&quot;)\n\nSynonyms:\nl4u/l4u_core.sym_list\nl4u/l4u_core sym_list","url":"l4u/l4u_core.html#sym_list"},{"doc":"l4u/l4u_core","title":"sym_quasiquote","content":"pub const sym_quasiquote: Expr = SYMBOL(&quot;quasiquote&quot;)\n\nSynonyms:\nl4u/l4u_core.sym_quasiquote\nl4u/l4u_core sym_quasiquote","url":"l4u/l4u_core.html#sym_quasiquote"},{"doc":"l4u/l4u_core","title":"sym_quote","content":"pub const sym_quote: Expr = SYMBOL(&quot;quote&quot;)\n\nSynonyms:\nl4u/l4u_core.sym_quote\nl4u/l4u_core sym_quote","url":"l4u/l4u_core.html#sym_quote"},{"doc":"l4u/l4u_core","title":"sym_unquote","content":"pub const sym_unquote: Expr = SYMBOL(&quot;unquote&quot;)\n\nSynonyms:\nl4u/l4u_core.sym_unquote\nl4u/l4u_core sym_unquote","url":"l4u/l4u_core.html#sym_unquote"},{"doc":"l4u/l4u_core","title":"sym_unquote_splicing","content":"pub const sym_unquote_splicing: Expr = SYMBOL(&quot;splice-unquote&quot;)\n\nSynonyms:\nl4u/l4u_core.sym_unquote_splicing\nl4u/l4u_core sym_unquote_splicing","url":"l4u/l4u_core.html#sym_unquote_splicing"},{"doc":"l4u/l4u_core","title":"add2","content":"pub fn add2(x: Expr, y: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.add2\nl4u/l4u_core add2","url":"l4u/l4u_core.html#add2"},{"doc":"l4u/l4u_core","title":"apply","content":"pub fn apply(env: Env, callable: Expr, args: List(Expr)) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.apply\nl4u/l4u_core apply","url":"l4u/l4u_core.html#apply"},{"doc":"l4u/l4u_core","title":"apply_macro","content":"pub fn apply_macro(expr: Expr, env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.apply_macro\nl4u/l4u_core apply_macro","url":"l4u/l4u_core.html#apply_macro"},{"doc":"l4u/l4u_core","title":"args_to_str","content":"pub fn args_to_str(args: List(Expr)) -&gt; String\n\nSynonyms:\nl4u/l4u_core.args_to_str\nl4u/l4u_core args_to_str","url":"l4u/l4u_core.html#args_to_str"},{"doc":"l4u/l4u_core","title":"bif_add","content":"pub fn bif_add(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_add\nl4u/l4u_core bif_add","url":"l4u/l4u_core.html#bif_add"},{"doc":"l4u/l4u_core","title":"bif_and","content":"pub fn bif_and(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_and\nl4u/l4u_core bif_and","url":"l4u/l4u_core.html#bif_and"},{"doc":"l4u/l4u_core","title":"bif_apply","content":"pub fn bif_apply(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_apply\nl4u/l4u_core bif_apply","url":"l4u/l4u_core.html#bif_apply"},{"doc":"l4u/l4u_core","title":"bif_assoc","content":"pub fn bif_assoc(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_assoc\nl4u/l4u_core bif_assoc","url":"l4u/l4u_core.html#bif_assoc"},{"doc":"l4u/l4u_core","title":"bif_atom","content":"pub fn bif_atom(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_atom\nl4u/l4u_core bif_atom","url":"l4u/l4u_core.html#bif_atom"},{"doc":"l4u/l4u_core","title":"bif_atomp","content":"pub fn bif_atomp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_atomp\nl4u/l4u_core bif_atomp","url":"l4u/l4u_core.html#bif_atomp"},{"doc":"l4u/l4u_core","title":"bif_car","content":"pub fn bif_car(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_car\nl4u/l4u_core bif_car","url":"l4u/l4u_core.html#bif_car"},{"doc":"l4u/l4u_core","title":"bif_cdr","content":"pub fn bif_cdr(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_cdr\nl4u/l4u_core bif_cdr","url":"l4u/l4u_core.html#bif_cdr"},{"doc":"l4u/l4u_core","title":"bif_cons","content":"pub fn bif_cons(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_cons\nl4u/l4u_core bif_cons","url":"l4u/l4u_core.html#bif_cons"},{"doc":"l4u/l4u_core","title":"bif_containsp","content":"pub fn bif_containsp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_containsp\nl4u/l4u_core bif_containsp","url":"l4u/l4u_core.html#bif_containsp"},{"doc":"l4u/l4u_core","title":"bif_count","content":"pub fn bif_count(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_count\nl4u/l4u_core bif_count","url":"l4u/l4u_core.html#bif_count"},{"doc":"l4u/l4u_core","title":"bif_custom_type_to_map","content":"pub fn bif_custom_type_to_map(\n  exprs: List(Expr),\n  env: Env,\n) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_custom_type_to_map\nl4u/l4u_core bif_custom_type_to_map","url":"l4u/l4u_core.html#bif_custom_type_to_map"},{"doc":"l4u/l4u_core","title":"bif_def_custom_type","content":"pub fn bif_def_custom_type(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_def_custom_type\nl4u/l4u_core bif_def_custom_type","url":"l4u/l4u_core.html#bif_def_custom_type"},{"doc":"l4u/l4u_core","title":"bif_deref","content":"pub fn bif_deref(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_deref\nl4u/l4u_core bif_deref","url":"l4u/l4u_core.html#bif_deref"},{"doc":"l4u/l4u_core","title":"bif_describe","content":"pub fn bif_describe(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_describe\nl4u/l4u_core bif_describe","url":"l4u/l4u_core.html#bif_describe"},{"doc":"l4u/l4u_core","title":"bif_dissoc","content":"pub fn bif_dissoc(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_dissoc\nl4u/l4u_core bif_dissoc","url":"l4u/l4u_core.html#bif_dissoc"},{"doc":"l4u/l4u_core","title":"bif_div","content":"pub fn bif_div(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_div\nl4u/l4u_core bif_div","url":"l4u/l4u_core.html#bif_div"},{"doc":"l4u/l4u_core","title":"bif_emptyp","content":"pub fn bif_emptyp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_emptyp\nl4u/l4u_core bif_emptyp","url":"l4u/l4u_core.html#bif_emptyp"},{"doc":"l4u/l4u_core","title":"bif_eqp","content":"pub fn bif_eqp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_eqp\nl4u/l4u_core bif_eqp","url":"l4u/l4u_core.html#bif_eqp"},{"doc":"l4u/l4u_core","title":"bif_eval","content":"pub fn bif_eval(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_eval\nl4u/l4u_core bif_eval","url":"l4u/l4u_core.html#bif_eval"},{"doc":"l4u/l4u_core","title":"bif_falsep","content":"pub fn bif_falsep(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_falsep\nl4u/l4u_core bif_falsep","url":"l4u/l4u_core.html#bif_falsep"},{"doc":"l4u/l4u_core","title":"bif_fnp","content":"pub fn bif_fnp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_fnp\nl4u/l4u_core bif_fnp","url":"l4u/l4u_core.html#bif_fnp"},{"doc":"l4u/l4u_core","title":"bif_gensym","content":"pub fn bif_gensym(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_gensym\nl4u/l4u_core bif_gensym","url":"l4u/l4u_core.html#bif_gensym"},{"doc":"l4u/l4u_core","title":"bif_get","content":"pub fn bif_get(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_get\nl4u/l4u_core bif_get","url":"l4u/l4u_core.html#bif_get"},{"doc":"l4u/l4u_core","title":"bif_global_get","content":"pub fn bif_global_get(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_global_get\nl4u/l4u_core bif_global_get","url":"l4u/l4u_core.html#bif_global_get"},{"doc":"l4u/l4u_core","title":"bif_global_keys","content":"pub fn bif_global_keys(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_global_keys\nl4u/l4u_core bif_global_keys","url":"l4u/l4u_core.html#bif_global_keys"},{"doc":"l4u/l4u_core","title":"bif_gteqp","content":"pub fn bif_gteqp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_gteqp\nl4u/l4u_core bif_gteqp","url":"l4u/l4u_core.html#bif_gteqp"},{"doc":"l4u/l4u_core","title":"bif_gtp","content":"pub fn bif_gtp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_gtp\nl4u/l4u_core bif_gtp","url":"l4u/l4u_core.html#bif_gtp"},{"doc":"l4u/l4u_core","title":"bif_hash_map","content":"pub fn bif_hash_map(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_hash_map\nl4u/l4u_core bif_hash_map","url":"l4u/l4u_core.html#bif_hash_map"},{"doc":"l4u/l4u_core","title":"bif_hash_mapp","content":"pub fn bif_hash_mapp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_hash_mapp\nl4u/l4u_core bif_hash_mapp","url":"l4u/l4u_core.html#bif_hash_mapp"},{"doc":"l4u/l4u_core","title":"bif_inspect","content":"pub fn bif_inspect(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_inspect\nl4u/l4u_core bif_inspect","url":"l4u/l4u_core.html#bif_inspect"},{"doc":"l4u/l4u_core","title":"bif_inspect_env","content":"pub fn bif_inspect_env(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_inspect_env\nl4u/l4u_core bif_inspect_env","url":"l4u/l4u_core.html#bif_inspect_env"},{"doc":"l4u/l4u_core","title":"bif_instanciate_custom_type","content":"pub fn bif_instanciate_custom_type(\n  exprs: List(Expr),\n  env: Env,\n) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_instanciate_custom_type\nl4u/l4u_core bif_instanciate_custom_type","url":"l4u/l4u_core.html#bif_instanciate_custom_type"},{"doc":"l4u/l4u_core","title":"bif_keys","content":"pub fn bif_keys(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_keys\nl4u/l4u_core bif_keys","url":"l4u/l4u_core.html#bif_keys"},{"doc":"l4u/l4u_core","title":"bif_keyword","content":"pub fn bif_keyword(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_keyword\nl4u/l4u_core bif_keyword","url":"l4u/l4u_core.html#bif_keyword"},{"doc":"l4u/l4u_core","title":"bif_keywordp","content":"pub fn bif_keywordp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_keywordp\nl4u/l4u_core bif_keywordp","url":"l4u/l4u_core.html#bif_keywordp"},{"doc":"l4u/l4u_core","title":"bif_list","content":"pub fn bif_list(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_list\nl4u/l4u_core bif_list","url":"l4u/l4u_core.html#bif_list"},{"doc":"l4u/l4u_core","title":"bif_listp","content":"pub fn bif_listp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_listp\nl4u/l4u_core bif_listp","url":"l4u/l4u_core.html#bif_listp"},{"doc":"l4u/l4u_core","title":"bif_load_file","content":"pub fn bif_load_file(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_load_file\nl4u/l4u_core bif_load_file","url":"l4u/l4u_core.html#bif_load_file"},{"doc":"l4u/l4u_core","title":"bif_lteqp","content":"pub fn bif_lteqp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_lteqp\nl4u/l4u_core bif_lteqp","url":"l4u/l4u_core.html#bif_lteqp"},{"doc":"l4u/l4u_core","title":"bif_ltp","content":"pub fn bif_ltp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_ltp\nl4u/l4u_core bif_ltp","url":"l4u/l4u_core.html#bif_ltp"},{"doc":"l4u/l4u_core","title":"bif_macrop","content":"pub fn bif_macrop(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_macrop\nl4u/l4u_core bif_macrop","url":"l4u/l4u_core.html#bif_macrop"},{"doc":"l4u/l4u_core","title":"bif_meta","content":"pub fn bif_meta(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_meta\nl4u/l4u_core bif_meta","url":"l4u/l4u_core.html#bif_meta"},{"doc":"l4u/l4u_core","title":"bif_mod","content":"pub fn bif_mod(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_mod\nl4u/l4u_core bif_mod","url":"l4u/l4u_core.html#bif_mod"},{"doc":"l4u/l4u_core","title":"bif_mul","content":"pub fn bif_mul(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_mul\nl4u/l4u_core bif_mul","url":"l4u/l4u_core.html#bif_mul"},{"doc":"l4u/l4u_core","title":"bif_nilp","content":"pub fn bif_nilp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_nilp\nl4u/l4u_core bif_nilp","url":"l4u/l4u_core.html#bif_nilp"},{"doc":"l4u/l4u_core","title":"bif_not","content":"pub fn bif_not(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_not\nl4u/l4u_core bif_not","url":"l4u/l4u_core.html#bif_not"},{"doc":"l4u/l4u_core","title":"bif_numberp","content":"pub fn bif_numberp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_numberp\nl4u/l4u_core bif_numberp","url":"l4u/l4u_core.html#bif_numberp"},{"doc":"l4u/l4u_core","title":"bif_or","content":"pub fn bif_or(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_or\nl4u/l4u_core bif_or","url":"l4u/l4u_core.html#bif_or"},{"doc":"l4u/l4u_core","title":"bif_pr_str","content":"pub fn bif_pr_str(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_pr_str\nl4u/l4u_core bif_pr_str","url":"l4u/l4u_core.html#bif_pr_str"},{"doc":"l4u/l4u_core","title":"bif_println","content":"pub fn bif_println(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_println\nl4u/l4u_core bif_println","url":"l4u/l4u_core.html#bif_println"},{"doc":"l4u/l4u_core","title":"bif_prn","content":"pub fn bif_prn(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_prn\nl4u/l4u_core bif_prn","url":"l4u/l4u_core.html#bif_prn"},{"doc":"l4u/l4u_core","title":"bif_progn","content":"pub fn bif_progn(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_progn\nl4u/l4u_core bif_progn","url":"l4u/l4u_core.html#bif_progn"},{"doc":"l4u/l4u_core","title":"bif_read","content":"pub fn bif_read(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_read\nl4u/l4u_core bif_read","url":"l4u/l4u_core.html#bif_read"},{"doc":"l4u/l4u_core","title":"bif_read_string","content":"pub fn bif_read_string(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_read_string\nl4u/l4u_core bif_read_string","url":"l4u/l4u_core.html#bif_read_string"},{"doc":"l4u/l4u_core","title":"bif_readline","content":"pub fn bif_readline(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_readline\nl4u/l4u_core bif_readline","url":"l4u/l4u_core.html#bif_readline"},{"doc":"l4u/l4u_core","title":"bif_reset","content":"pub fn bif_reset(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_reset\nl4u/l4u_core bif_reset","url":"l4u/l4u_core.html#bif_reset"},{"doc":"l4u/l4u_core","title":"bif_sequentialp","content":"pub fn bif_sequentialp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_sequentialp\nl4u/l4u_core bif_sequentialp","url":"l4u/l4u_core.html#bif_sequentialp"},{"doc":"l4u/l4u_core","title":"bif_show","content":"pub fn bif_show(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_show\nl4u/l4u_core bif_show","url":"l4u/l4u_core.html#bif_show"},{"doc":"l4u/l4u_core","title":"bif_slurp","content":"pub fn bif_slurp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_slurp\nl4u/l4u_core bif_slurp","url":"l4u/l4u_core.html#bif_slurp"},{"doc":"l4u/l4u_core","title":"bif_str","content":"pub fn bif_str(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_str\nl4u/l4u_core bif_str","url":"l4u/l4u_core.html#bif_str"},{"doc":"l4u/l4u_core","title":"bif_stringp","content":"pub fn bif_stringp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_stringp\nl4u/l4u_core bif_stringp","url":"l4u/l4u_core.html#bif_stringp"},{"doc":"l4u/l4u_core","title":"bif_sub","content":"pub fn bif_sub(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_sub\nl4u/l4u_core bif_sub","url":"l4u/l4u_core.html#bif_sub"},{"doc":"l4u/l4u_core","title":"bif_symbol","content":"pub fn bif_symbol(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_symbol\nl4u/l4u_core bif_symbol","url":"l4u/l4u_core.html#bif_symbol"},{"doc":"l4u/l4u_core","title":"bif_symbolp","content":"pub fn bif_symbolp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_symbolp\nl4u/l4u_core bif_symbolp","url":"l4u/l4u_core.html#bif_symbolp"},{"doc":"l4u/l4u_core","title":"bif_throw","content":"pub fn bif_throw(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_throw\nl4u/l4u_core bif_throw","url":"l4u/l4u_core.html#bif_throw"},{"doc":"l4u/l4u_core","title":"bif_time_ms","content":"pub fn bif_time_ms(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_time_ms\nl4u/l4u_core bif_time_ms","url":"l4u/l4u_core.html#bif_time_ms"},{"doc":"l4u/l4u_core","title":"bif_to_hash_map","content":"pub fn bif_to_hash_map(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_to_hash_map\nl4u/l4u_core bif_to_hash_map","url":"l4u/l4u_core.html#bif_to_hash_map"},{"doc":"l4u/l4u_core","title":"bif_tokenize","content":"pub fn bif_tokenize(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_tokenize\nl4u/l4u_core bif_tokenize","url":"l4u/l4u_core.html#bif_tokenize"},{"doc":"l4u/l4u_core","title":"bif_trace","content":"pub fn bif_trace(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_trace\nl4u/l4u_core bif_trace","url":"l4u/l4u_core.html#bif_trace"},{"doc":"l4u/l4u_core","title":"bif_trace_clear","content":"pub fn bif_trace_clear(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_trace_clear\nl4u/l4u_core bif_trace_clear","url":"l4u/l4u_core.html#bif_trace_clear"},{"doc":"l4u/l4u_core","title":"bif_truep","content":"pub fn bif_truep(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_truep\nl4u/l4u_core bif_truep","url":"l4u/l4u_core.html#bif_truep"},{"doc":"l4u/l4u_core","title":"bif_vals","content":"pub fn bif_vals(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_vals\nl4u/l4u_core bif_vals","url":"l4u/l4u_core.html#bif_vals"},{"doc":"l4u/l4u_core","title":"bif_vec","content":"pub fn bif_vec(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_vec\nl4u/l4u_core bif_vec","url":"l4u/l4u_core.html#bif_vec"},{"doc":"l4u/l4u_core","title":"bif_vector","content":"pub fn bif_vector(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_vector\nl4u/l4u_core bif_vector","url":"l4u/l4u_core.html#bif_vector"},{"doc":"l4u/l4u_core","title":"bif_vectorp","content":"pub fn bif_vectorp(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_vectorp\nl4u/l4u_core bif_vectorp","url":"l4u/l4u_core.html#bif_vectorp"},{"doc":"l4u/l4u_core","title":"bif_with_meta","content":"pub fn bif_with_meta(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bif_with_meta\nl4u/l4u_core bif_with_meta","url":"l4u/l4u_core.html#bif_with_meta"},{"doc":"l4u/l4u_core","title":"bispform_def","content":"pub fn bispform_def(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_def\nl4u/l4u_core bispform_def","url":"l4u/l4u_core.html#bispform_def"},{"doc":"l4u/l4u_core","title":"bispform_defmacro","content":"pub fn bispform_defmacro(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_defmacro\nl4u/l4u_core bispform_defmacro","url":"l4u/l4u_core.html#bispform_defmacro"},{"doc":"l4u/l4u_core","title":"bispform_erase","content":"pub fn bispform_erase(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_erase\nl4u/l4u_core bispform_erase","url":"l4u/l4u_core.html#bispform_erase"},{"doc":"l4u/l4u_core","title":"bispform_fn","content":"pub fn bispform_fn(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_fn\nl4u/l4u_core bispform_fn","url":"l4u/l4u_core.html#bispform_fn"},{"doc":"l4u/l4u_core","title":"bispform_if","content":"pub fn bispform_if(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_if\nl4u/l4u_core bispform_if","url":"l4u/l4u_core.html#bispform_if"},{"doc":"l4u/l4u_core","title":"bispform_let","content":"pub fn bispform_let(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_let\nl4u/l4u_core bispform_let","url":"l4u/l4u_core.html#bispform_let"},{"doc":"l4u/l4u_core","title":"bispform_macro","content":"pub fn bispform_macro(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_macro\nl4u/l4u_core bispform_macro","url":"l4u/l4u_core.html#bispform_macro"},{"doc":"l4u/l4u_core","title":"bispform_macroexpand","content":"pub fn bispform_macroexpand(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_macroexpand\nl4u/l4u_core bispform_macroexpand","url":"l4u/l4u_core.html#bispform_macroexpand"},{"doc":"l4u/l4u_core","title":"bispform_macroexpand_all","content":"pub fn bispform_macroexpand_all(\n  exprs: List(Expr),\n  env: Env,\n) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_macroexpand_all\nl4u/l4u_core bispform_macroexpand_all","url":"l4u/l4u_core.html#bispform_macroexpand_all"},{"doc":"l4u/l4u_core","title":"bispform_quasiquote","content":"pub fn bispform_quasiquote(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_quasiquote\nl4u/l4u_core bispform_quasiquote","url":"l4u/l4u_core.html#bispform_quasiquote"},{"doc":"l4u/l4u_core","title":"bispform_quasiquote2","content":"pub fn bispform_quasiquote2(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_quasiquote2\nl4u/l4u_core bispform_quasiquote2","url":"l4u/l4u_core.html#bispform_quasiquote2"},{"doc":"l4u/l4u_core","title":"bispform_quasiquote_expand","content":"pub fn bispform_quasiquote_expand(\n  exprs: List(Expr),\n  env: Env,\n) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_quasiquote_expand\nl4u/l4u_core bispform_quasiquote_expand","url":"l4u/l4u_core.html#bispform_quasiquote_expand"},{"doc":"l4u/l4u_core","title":"bispform_quasiquote_expand2","content":"pub fn bispform_quasiquote_expand2(\n  exprs: List(Expr),\n  env: Env,\n) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_quasiquote_expand2\nl4u/l4u_core bispform_quasiquote_expand2","url":"l4u/l4u_core.html#bispform_quasiquote_expand2"},{"doc":"l4u/l4u_core","title":"bispform_quote","content":"pub fn bispform_quote(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_quote\nl4u/l4u_core bispform_quote","url":"l4u/l4u_core.html#bispform_quote"},{"doc":"l4u/l4u_core","title":"bispform_try","content":"pub fn bispform_try(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.bispform_try\nl4u/l4u_core bispform_try","url":"l4u/l4u_core.html#bispform_try"},{"doc":"l4u/l4u_core","title":"compare","content":"pub fn compare(u: Expr, v: Expr) -&gt; Order\n\nSynonyms:\nl4u/l4u_core.compare\nl4u/l4u_core compare","url":"l4u/l4u_core.html#compare"},{"doc":"l4u/l4u_core","title":"compare_dict","content":"pub fn compare_dict(us: List(Expr), vs: List(Expr)) -&gt; Order\n\nSynonyms:\nl4u/l4u_core.compare_dict\nl4u/l4u_core compare_dict","url":"l4u/l4u_core.html#compare_dict"},{"doc":"l4u/l4u_core","title":"compare_list","content":"pub fn compare_list(us: List(Expr), vs: List(Expr)) -&gt; Order\n\nSynonyms:\nl4u/l4u_core.compare_list\nl4u/l4u_core compare_list","url":"l4u/l4u_core.html#compare_list"},{"doc":"l4u/l4u_core","title":"describe","content":"pub fn describe(expr: Expr) -&gt; String\n\nSynonyms:\nl4u/l4u_core.describe\nl4u/l4u_core describe","url":"l4u/l4u_core.html#describe"},{"doc":"l4u/l4u_core","title":"description","content":"pub fn description(name: String) -&gt; Description\n\nSynonyms:\nl4u/l4u_core.description\nl4u/l4u_core description","url":"l4u/l4u_core.html#description"},{"doc":"l4u/l4u_core","title":"description_with_text","content":"pub fn description_with_text(\n  name: String,\n  text: String,\n) -&gt; Description\n\nSynonyms:\nl4u/l4u_core.description_with_text\nl4u/l4u_core description_with_text","url":"l4u/l4u_core.html#description_with_text"},{"doc":"l4u/l4u_core","title":"dict_to_str","content":"pub fn dict_to_str(dict: Dict(String, Expr)) -&gt; String\n\nSynonyms:\nl4u/l4u_core.dict_to_str\nl4u/l4u_core dict_to_str","url":"l4u/l4u_core.html#dict_to_str"},{"doc":"l4u/l4u_core","title":"div2","content":"pub fn div2(x: Expr, y: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.div2\nl4u/l4u_core div2","url":"l4u/l4u_core.html#div2"},{"doc":"l4u/l4u_core","title":"dump_closure","content":"pub fn dump_closure(msg: String, expr: Expr) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.dump_closure\nl4u/l4u_core dump_closure","url":"l4u/l4u_core.html#dump_closure"},{"doc":"l4u/l4u_core","title":"dump_dict","content":"pub fn dump_dict(dict: Dict(String, Expr), env: Env) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.dump_dict\nl4u/l4u_core dump_dict","url":"l4u/l4u_core.html#dump_dict"},{"doc":"l4u/l4u_core","title":"dump_env","content":"pub fn dump_env(title: String, env: Env) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.dump_env\nl4u/l4u_core dump_env","url":"l4u/l4u_core.html#dump_env"},{"doc":"l4u/l4u_core","title":"env_add_local_scope","content":"pub fn env_add_local_scope(env: Env, scope: Scope) -&gt; Env\n\nSynonyms:\nl4u/l4u_core.env_add_local_scope\nl4u/l4u_core env_add_local_scope","url":"l4u/l4u_core.html#env_add_local_scope"},{"doc":"l4u/l4u_core","title":"env_erase_global","content":"pub fn env_erase_global(env: Env, key: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.env_erase_global\nl4u/l4u_core env_erase_global","url":"l4u/l4u_core.html#env_erase_global"},{"doc":"l4u/l4u_core","title":"env_get","content":"pub fn env_get(env: Env, key: String) -&gt; Result(Expr, String)\n\nSynonyms:\nl4u/l4u_core.env_get\nl4u/l4u_core env_get","url":"l4u/l4u_core.html#env_get"},{"doc":"l4u/l4u_core","title":"env_get_global","content":"pub fn env_get_global(env: Env, key: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.env_get_global\nl4u/l4u_core env_get_global","url":"l4u/l4u_core.html#env_get_global"},{"doc":"l4u/l4u_core","title":"env_get_global_aux","content":"pub fn env_get_global_aux(env: Env, key: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.env_get_global_aux\nl4u/l4u_core env_get_global_aux","url":"l4u/l4u_core.html#env_get_global_aux"},{"doc":"l4u/l4u_core","title":"env_get_global_keys","content":"pub fn env_get_global_keys(env: Env) -&gt; List(String)\n\nSynonyms:\nl4u/l4u_core.env_get_global_keys\nl4u/l4u_core env_get_global_keys","url":"l4u/l4u_core.html#env_get_global_keys"},{"doc":"l4u/l4u_core","title":"env_get_toplevel","content":"pub fn env_get_toplevel(env: Env) -&gt; Env\n\nSynonyms:\nl4u/l4u_core.env_get_toplevel\nl4u/l4u_core env_get_toplevel","url":"l4u/l4u_core.html#env_get_toplevel"},{"doc":"l4u/l4u_core","title":"env_replace_local_scope","content":"pub fn env_replace_local_scope(env: Env, scope: Scope) -&gt; Env\n\nSynonyms:\nl4u/l4u_core.env_replace_local_scope\nl4u/l4u_core env_replace_local_scope","url":"l4u/l4u_core.html#env_replace_local_scope"},{"doc":"l4u/l4u_core","title":"env_set_global","content":"pub fn env_set_global(env: Env, key: String, value: Expr) -&gt; Env\n\nSynonyms:\nl4u/l4u_core.env_set_global\nl4u/l4u_core env_set_global","url":"l4u/l4u_core.html#env_set_global"},{"doc":"l4u/l4u_core","title":"env_set_local","content":"pub fn env_set_local(env: Env, key: String, value: Expr) -&gt; Env\n\nSynonyms:\nl4u/l4u_core.env_set_local\nl4u/l4u_core env_set_local","url":"l4u/l4u_core.html#env_set_local"},{"doc":"l4u/l4u_core","title":"env_update_global_aux","content":"pub fn env_update_global_aux(\n  env: Env,\n  key: String,\n  property_name: Expr,\n  property_value: Expr,\n) -&gt; Nil\n\nSynonyms:\nl4u/l4u_core.env_update_global_aux\nl4u/l4u_core env_update_global_aux","url":"l4u/l4u_core.html#env_update_global_aux"},{"doc":"l4u/l4u_core","title":"eval","content":"pub fn eval(exprs: List(Expr), result: Expr, env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.eval\nl4u/l4u_core eval","url":"l4u/l4u_core.html#eval"},{"doc":"l4u/l4u_core","title":"eval_contents","content":"pub fn eval_contents(\n  exprs: List(Expr),\n  acc: List(Expr),\n  env: Env,\n) -&gt; #(List(Expr), Env)\n\nSynonyms:\nl4u/l4u_core.eval_contents\nl4u/l4u_core eval_contents","url":"l4u/l4u_core.html#eval_contents"},{"doc":"l4u/l4u_core","title":"eval_expr","content":"pub fn eval_expr(expr: Expr, env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.eval_expr\nl4u/l4u_core eval_expr","url":"l4u/l4u_core.html#eval_expr"},{"doc":"l4u/l4u_core","title":"eval_funcall_args","content":"pub fn eval_funcall_args(\n  exprs: List(Expr),\n  env: Env,\n) -&gt; #(List(Expr), Env)\n\nSynonyms:\nl4u/l4u_core.eval_funcall_args\nl4u/l4u_core eval_funcall_args","url":"l4u/l4u_core.html#eval_funcall_args"},{"doc":"l4u/l4u_core","title":"generate_new_env","content":"pub fn generate_new_env(\n  pdic: PDic,\n  default_bindings: Dict(String, Expr),\n  init_files: List(String),\n) -&gt; Env\n\nSynonyms:\nl4u/l4u_core.generate_new_env\nl4u/l4u_core generate_new_env","url":"l4u/l4u_core.html#generate_new_env"},{"doc":"l4u/l4u_core","title":"get_bif_result_value","content":"pub fn get_bif_result_value(expr: Expr) -&gt; a\n\nSynonyms:\nl4u/l4u_core.get_bif_result_value\nl4u/l4u_core get_bif_result_value","url":"l4u/l4u_core.html#get_bif_result_value"},{"doc":"l4u/l4u_core","title":"get_contents","content":"pub fn get_contents(expr: Expr) -&gt; List(Expr)\n\nSynonyms:\nl4u/l4u_core.get_contents\nl4u/l4u_core get_contents","url":"l4u/l4u_core.html#get_contents"},{"doc":"l4u/l4u_core","title":"get_macro","content":"pub fn get_macro(env: Env, ast: Expr) -&gt; Result(Expr, String)\n\nSynonyms:\nl4u/l4u_core.get_macro\nl4u/l4u_core get_macro","url":"l4u/l4u_core.html#get_macro"},{"doc":"l4u/l4u_core","title":"global_keys","content":"pub fn global_keys(prefix: String, env: Env) -&gt; List(String)\n\nSynonyms:\nl4u/l4u_core.global_keys\nl4u/l4u_core global_keys","url":"l4u/l4u_core.html#global_keys"},{"doc":"l4u/l4u_core","title":"indent","content":"pub fn indent(level: Int) -&gt; String\n\nSynonyms:\nl4u/l4u_core.indent\nl4u/l4u_core indent","url":"l4u/l4u_core.html#indent"},{"doc":"l4u/l4u_core","title":"info_to_str","content":"pub fn info_to_str(inf: Info) -&gt; String\n\nSynonyms:\nl4u/l4u_core.info_to_str\nl4u/l4u_core info_to_str","url":"l4u/l4u_core.html#info_to_str"},{"doc":"l4u/l4u_core","title":"initialize","content":"pub fn initialize() -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.initialize\nl4u/l4u_core initialize","url":"l4u/l4u_core.html#initialize"},{"doc":"l4u/l4u_core","title":"inspect","content":"pub fn inspect(expr: Expr) -&gt; String\n\nSynonyms:\nl4u/l4u_core.inspect\nl4u/l4u_core inspect","url":"l4u/l4u_core.html#inspect"},{"doc":"l4u/l4u_core","title":"intern_keyword","content":"pub fn intern_keyword(str: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.intern_keyword\nl4u/l4u_core intern_keyword","url":"l4u/l4u_core.html#intern_keyword"},{"doc":"l4u/l4u_core","title":"intern_symbol","content":"pub fn intern_symbol(str: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.intern_symbol\nl4u/l4u_core intern_symbol","url":"l4u/l4u_core.html#intern_symbol"},{"doc":"l4u/l4u_core","title":"intern_symbol_or_keyword","content":"pub fn intern_symbol_or_keyword(str: String) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.intern_symbol_or_keyword\nl4u/l4u_core intern_symbol_or_keyword","url":"l4u/l4u_core.html#intern_symbol_or_keyword"},{"doc":"l4u/l4u_core","title":"is_empty_value","content":"pub fn is_empty_value(val: Expr) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.is_empty_value\nl4u/l4u_core is_empty_value","url":"l4u/l4u_core.html#is_empty_value"},{"doc":"l4u/l4u_core","title":"is_equal","content":"pub fn is_equal(first: Expr, second: Expr) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.is_equal\nl4u/l4u_core is_equal","url":"l4u/l4u_core.html#is_equal"},{"doc":"l4u/l4u_core","title":"is_false_value","content":"pub fn is_false_value(val: Expr) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.is_false_value\nl4u/l4u_core is_false_value","url":"l4u/l4u_core.html#is_false_value"},{"doc":"l4u/l4u_core","title":"is_nil_value","content":"pub fn is_nil_value(val: Expr) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.is_nil_value\nl4u/l4u_core is_nil_value","url":"l4u/l4u_core.html#is_nil_value"},{"doc":"l4u/l4u_core","title":"is_true_condition","content":"pub fn is_true_condition(e: Expr) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.is_true_condition\nl4u/l4u_core is_true_condition","url":"l4u/l4u_core.html#is_true_condition"},{"doc":"l4u/l4u_core","title":"is_true_value","content":"pub fn is_true_value(val: Expr) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.is_true_value\nl4u/l4u_core is_true_value","url":"l4u/l4u_core.html#is_true_value"},{"doc":"l4u/l4u_core","title":"local_scopes_to_string","content":"pub fn local_scopes_to_string(\n  scopes: List(Scope),\n  acc: List(String),\n) -&gt; String\n\nSynonyms:\nl4u/l4u_core.local_scopes_to_string\nl4u/l4u_core local_scopes_to_string","url":"l4u/l4u_core.html#local_scopes_to_string"},{"doc":"l4u/l4u_core","title":"macroexpand","content":"pub fn macroexpand(env: Env, ast: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.macroexpand\nl4u/l4u_core macroexpand","url":"l4u/l4u_core.html#macroexpand"},{"doc":"l4u/l4u_core","title":"macroexpand_all","content":"pub fn macroexpand_all(env: Env, ast: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.macroexpand_all\nl4u/l4u_core macroexpand_all","url":"l4u/l4u_core.html#macroexpand_all"},{"doc":"l4u/l4u_core","title":"main","content":"pub fn main() -&gt; a\n\nSynonyms:\nl4u/l4u_core.main\nl4u/l4u_core main","url":"l4u/l4u_core.html#main"},{"doc":"l4u/l4u_core","title":"make_container","content":"pub fn make_container(\n  template_expr: Expr,\n  contents: List(Expr),\n) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.make_container\nl4u/l4u_core make_container","url":"l4u/l4u_core.html#make_container"},{"doc":"l4u/l4u_core","title":"make_new_l4u_core_env","content":"pub fn make_new_l4u_core_env(\n  pdic: PDic,\n  bifs: List(#(String, Expr)),\n  files: List(String),\n) -&gt; Env\n\nSynonyms:\nl4u/l4u_core.make_new_l4u_core_env\nl4u/l4u_core make_new_l4u_core_env","url":"l4u/l4u_core.html#make_new_l4u_core_env"},{"doc":"l4u/l4u_core","title":"map_to_plist","content":"pub fn map_to_plist(\n  mapdata: Dict(String, Expr),\n  acc: List(Expr),\n) -&gt; List(Expr)\n\nSynonyms:\nl4u/l4u_core.map_to_plist\nl4u/l4u_core map_to_plist","url":"l4u/l4u_core.html#map_to_plist"},{"doc":"l4u/l4u_core","title":"mul2","content":"pub fn mul2(x: Expr, y: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.mul2\nl4u/l4u_core mul2","url":"l4u/l4u_core.html#mul2"},{"doc":"l4u/l4u_core","title":"parse","content":"pub fn parse(\n  tokens: List(String),\n  env: Env,\n) -&gt; #(Expr, List(String))\n\nSynonyms:\nl4u/l4u_core.parse\nl4u/l4u_core parse","url":"l4u/l4u_core.html#parse"},{"doc":"l4u/l4u_core","title":"parse_expr","content":"pub fn parse_expr(token: String, env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.parse_expr\nl4u/l4u_core parse_expr","url":"l4u/l4u_core.html#parse_expr"},{"doc":"l4u/l4u_core","title":"parse_list","content":"pub fn parse_list(\n  tokens: List(String),\n  acc: List(Expr),\n  terminator: String,\n  env: Env,\n) -&gt; #(List(Expr), List(String))\n\nSynonyms:\nl4u/l4u_core.parse_list\nl4u/l4u_core parse_list","url":"l4u/l4u_core.html#parse_list"},{"doc":"l4u/l4u_core","title":"parse_string","content":"pub fn parse_string(str: String, env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.parse_string\nl4u/l4u_core parse_string","url":"l4u/l4u_core.html#parse_string"},{"doc":"l4u/l4u_core","title":"parse_string_block","content":"pub fn parse_string_block(str: String, env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.parse_string_block\nl4u/l4u_core parse_string_block","url":"l4u/l4u_core.html#parse_string_block"},{"doc":"l4u/l4u_core","title":"plist_to_map","content":"pub fn plist_to_map(\n  plist: List(Expr),\n  acc: Dict(String, Expr),\n) -&gt; Dict(String, Expr)\n\nSynonyms:\nl4u/l4u_core.plist_to_map\nl4u/l4u_core plist_to_map","url":"l4u/l4u_core.html#plist_to_map"},{"doc":"l4u/l4u_core","title":"print","content":"pub fn print(expr: Expr) -&gt; String\n\nSynonyms:\nl4u/l4u_core.print\nl4u/l4u_core print","url":"l4u/l4u_core.html#print"},{"doc":"l4u/l4u_core","title":"print_2","content":"pub fn print_2(expr: Expr) -&gt; String\n\nSynonyms:\nl4u/l4u_core.print_2\nl4u/l4u_core print_2","url":"l4u/l4u_core.html#print_2"},{"doc":"l4u/l4u_core","title":"pstr","content":"pub fn pstr(expr: Expr) -&gt; String\n\nSynonyms:\nl4u/l4u_core.pstr\nl4u/l4u_core pstr","url":"l4u/l4u_core.html#pstr"},{"doc":"l4u/l4u_core","title":"quasiquote_","content":"pub fn quasiquote_(expr: Expr, env: Env) -&gt; #(List(Expr), Env)\n\nSynonyms:\nl4u/l4u_core.quasiquote_\nl4u/l4u_core quasiquote_","url":"l4u/l4u_core.html#quasiquote_"},{"doc":"l4u/l4u_core","title":"read","content":"pub fn read(src: String, env: Env) -&gt; List(Expr)\n\nSynonyms:\nl4u/l4u_core.read\nl4u/l4u_core read","url":"l4u/l4u_core.html#read"},{"doc":"l4u/l4u_core","title":"rep","content":"pub fn rep(src: String, env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.rep\nl4u/l4u_core rep","url":"l4u/l4u_core.html#rep"},{"doc":"l4u/l4u_core","title":"repl","content":"pub fn repl(env: Env, prompt: String) -&gt; a\n\nSynonyms:\nl4u/l4u_core.repl\nl4u/l4u_core repl","url":"l4u/l4u_core.html#repl"},{"doc":"l4u/l4u_core","title":"repl_print","content":"pub fn repl_print(result: Expr) -&gt; Nil\n\nSynonyms:\nl4u/l4u_core.repl_print\nl4u/l4u_core repl_print","url":"l4u/l4u_core.html#repl_print"},{"doc":"l4u/l4u_core","title":"show","content":"pub fn show(expr: Expr) -&gt; String\n\nSynonyms:\nl4u/l4u_core.show\nl4u/l4u_core show","url":"l4u/l4u_core.html#show"},{"doc":"l4u/l4u_core","title":"string_trim","content":"pub fn string_trim(source: String) -&gt; String\n\nSynonyms:\nl4u/l4u_core.string_trim\nl4u/l4u_core string_trim","url":"l4u/l4u_core.html#string_trim"},{"doc":"l4u/l4u_core","title":"sub2","content":"pub fn sub2(x: Expr, y: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.sub2\nl4u/l4u_core sub2","url":"l4u/l4u_core.html#sub2"},{"doc":"l4u/l4u_core","title":"to_l4u_bool","content":"pub fn to_l4u_bool(flag: Bool) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.to_l4u_bool\nl4u/l4u_core to_l4u_bool","url":"l4u/l4u_core.html#to_l4u_bool"},{"doc":"l4u/l4u_core","title":"to_simple_str","content":"pub fn to_simple_str(expr: Expr) -&gt; String\n\nSynonyms:\nl4u/l4u_core.to_simple_str\nl4u/l4u_core to_simple_str","url":"l4u/l4u_core.html#to_simple_str"},{"doc":"l4u/l4u_core","title":"tokenize","content":"pub fn tokenize(src: String, env: Env) -&gt; List(String)\n\nSynonyms:\nl4u/l4u_core.tokenize\nl4u/l4u_core tokenize","url":"l4u/l4u_core.html#tokenize"},{"doc":"l4u/l4u_core","title":"trace_closure_call","content":"pub fn trace_closure_call(\n  env: Env,\n  callable: Expr,\n  ecallable: a,\n  bindings: Dict(String, Expr),\n) -&gt; Int\n\nSynonyms:\nl4u/l4u_core.trace_closure_call\nl4u/l4u_core trace_closure_call","url":"l4u/l4u_core.html#trace_closure_call"},{"doc":"l4u/l4u_core","title":"trace_closure_return","content":"pub fn trace_closure_return(\n  env: Env,\n  callable: Expr,\n  ecallable: a,\n  rexpr: Expr,\n  ip: Int,\n) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.trace_closure_return\nl4u/l4u_core trace_closure_return","url":"l4u/l4u_core.html#trace_closure_return"},{"doc":"l4u/l4u_core","title":"trace_set_last_expr","content":"pub fn trace_set_last_expr(expr: Expr, env: Env) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.trace_set_last_expr\nl4u/l4u_core trace_set_last_expr","url":"l4u/l4u_core.html#trace_set_last_expr"},{"doc":"l4u/l4u_core","title":"trace_set_last_funcall","content":"pub fn trace_set_last_funcall(expr: Expr, env: Env) -&gt; Bool\n\nSynonyms:\nl4u/l4u_core.trace_set_last_funcall\nl4u/l4u_core trace_set_last_funcall","url":"l4u/l4u_core.html#trace_set_last_funcall"},{"doc":"l4u/l4u_core","title":"uneval","content":"pub fn uneval(expr: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.uneval\nl4u/l4u_core uneval","url":"l4u/l4u_core.html#uneval"},{"doc":"l4u/l4u_core","title":"unwrap","content":"pub fn unwrap(expr: Expr) -&gt; Expr\n\nSynonyms:\nl4u/l4u_core.unwrap\nl4u/l4u_core unwrap","url":"l4u/l4u_core.html#unwrap"},{"doc":"l4u/l4u_core","title":"vars_to_string","content":"pub fn vars_to_string(vars: Dict(String, Expr)) -&gt; String\n\nSynonyms:\nl4u/l4u_core.vars_to_string\nl4u/l4u_core vars_to_string","url":"l4u/l4u_core.html#vars_to_string"},{"doc":"l4u/l4u_core","title":"l4u/l4u_core","content":"let assert [Scope(tvars), ..] = closure_env.scopes","url":"l4u/l4u_core.html"},{"doc":"l4u/bif_lib","title":"bif_lib_def","content":"pub fn bif_lib_def() -&gt; List(#(String, Expr))\n\nSynonyms:\nl4u/bif_lib.bif_lib_def\nl4u/bif_lib bif_lib_def","url":"l4u/bif_lib.html#bif_lib_def"},{"doc":"l4u/bif_lib","title":"erlang_module_of","content":"pub fn erlang_module_of(exprs: List(Expr)) -&gt; String\n\nSynonyms:\nl4u/bif_lib.erlang_module_of\nl4u/bif_lib erlang_module_of","url":"l4u/bif_lib.html#erlang_module_of"},{"doc":"l4u/bif_lib","title":"invoke_native_function","content":"pub fn invoke_native_function(\n  native_fun: Expr,\n  args: List(Expr),\n) -&gt; Expr\n\nSynonyms:\nl4u/bif_lib.invoke_native_function\nl4u/bif_lib invoke_native_function","url":"l4u/bif_lib.html#invoke_native_function"},{"doc":"l4u/bif_lib","title":"moddir_to_modulename","content":"pub fn moddir_to_modulename(moddir: List(Expr)) -&gt; String\n\nSynonyms:\nl4u/bif_lib.moddir_to_modulename\nl4u/bif_lib moddir_to_modulename","url":"l4u/bif_lib.html#moddir_to_modulename"},{"doc":"l4u/bif_lib","title":"l4u/bif_lib","content":"","url":"l4u/bif_lib.html"},{"doc":"l4u/bif_string","title":"bif_string_def","content":"pub fn bif_string_def() -&gt; List(#(String, Expr))\n\nSynonyms:\nl4u/bif_string.bif_string_def\nl4u/bif_string bif_string_def","url":"l4u/bif_string.html#bif_string_def"},{"doc":"l4u/bif_string","title":"l4u/bif_string","content":"","url":"l4u/bif_string.html"},{"doc":"l4u/plist","title":"plist_get_bool","content":"pub fn plist_get_bool(\n  plist: List(Expr),\n  key: String,\n) -&gt; Option(Bool)\n\nSynonyms:\nl4u/plist.plist_get_bool\nl4u/plist plist_get_bool","url":"l4u/plist.html#plist_get_bool"},{"doc":"l4u/plist","title":"plist_get_bool_with_default","content":"pub fn plist_get_bool_with_default(\n  plist: List(Expr),\n  key: String,\n  default: Bool,\n) -&gt; Bool\n\nSynonyms:\nl4u/plist.plist_get_bool_with_default\nl4u/plist plist_get_bool_with_default","url":"l4u/plist.html#plist_get_bool_with_default"},{"doc":"l4u/plist","title":"plist_get_int","content":"pub fn plist_get_int(\n  plist: List(Expr),\n  key: String,\n) -&gt; Option(Int)\n\nSynonyms:\nl4u/plist.plist_get_int\nl4u/plist plist_get_int","url":"l4u/plist.html#plist_get_int"},{"doc":"l4u/plist","title":"plist_get_int_with_default","content":"pub fn plist_get_int_with_default(\n  plist: List(Expr),\n  key: String,\n  default: Int,\n) -&gt; Int\n\nSynonyms:\nl4u/plist.plist_get_int_with_default\nl4u/plist plist_get_int_with_default","url":"l4u/plist.html#plist_get_int_with_default"},{"doc":"l4u/plist","title":"plist_get_str","content":"pub fn plist_get_str(\n  plist: List(Expr),\n  key: String,\n) -&gt; Option(String)\n\nSynonyms:\nl4u/plist.plist_get_str\nl4u/plist plist_get_str","url":"l4u/plist.html#plist_get_str"},{"doc":"l4u/plist","title":"plist_get_str_with_default","content":"pub fn plist_get_str_with_default(\n  plist: List(Expr),\n  key: String,\n  default: String,\n) -&gt; String\n\nSynonyms:\nl4u/plist.plist_get_str_with_default\nl4u/plist plist_get_str_with_default","url":"l4u/plist.html#plist_get_str_with_default"},{"doc":"l4u/plist","title":"l4u/plist","content":"","url":"l4u/plist.html"},{"doc":"l4u/bif_file","title":"bif_file_def","content":"pub fn bif_file_def() -&gt; List(#(String, Expr))\n\nSynonyms:\nl4u/bif_file.bif_file_def\nl4u/bif_file bif_file_def","url":"l4u/bif_file.html#bif_file_def"},{"doc":"l4u/bif_file","title":"scan_directory","content":"pub fn scan_directory(\n  path: String,\n  max_depth: Int,\n) -&gt; List(String)\n\nSynonyms:\nl4u/bif_file.scan_directory\nl4u/bif_file scan_directory","url":"l4u/bif_file.html#scan_directory"},{"doc":"l4u/bif_file","title":"l4u/bif_file","content":"","url":"l4u/bif_file.html"},{"doc":"l4u/l4u_obj","title":"L4uObj","content":"pub type L4uObj {\n  L4uObj(\n    name: String,\n    pid: Pid,\n    get_env: fn() -&gt; Env,\n    eval: fn(List(Expr)) -&gt; Result(Expr, String),\n    read: fn(String) -&gt; Result(List(Expr), String),\n    print: fn(Expr) -&gt; String,\n  )\n}\n L4uobj is a type that can operate an object that keeps the condition like the so called object oriented language.\nL4uObj(\n  name: String,\n  pid: Pid,\n  get_env: fn() -&gt; Env,\n  eval: fn(List(Expr)) -&gt; Result(Expr, String),\n  read: fn(String) -&gt; Result(List(Expr), String),\n  print: fn(Expr) -&gt; String,\n)\n\nname\n&lt;p&gt;Name of this L4uObj.&lt;/p&gt;\n\npid\n&lt;p&gt;PID of the process where EVAL is executed.&lt;/p&gt;\n\nget_env\n&lt;p&gt;Get the current environment of the L4uObj. &lt;/p&gt;\n\neval\n&lt;p&gt;Evaluate the given list of s-expressions in the environment&lt;/p&gt;\n\nread\n&lt;p&gt;Read the given string and return the list of s-expressions.&lt;/p&gt;\n\nprint\n&lt;p&gt;Print the given s-expression and return the string representation.&lt;/p&gt;\n\nSynonyms:\nl4u/l4u_obj.L4uObj\nl4u/l4u_obj L4uObj","url":"l4u/l4u_obj.html#L4uObj"},{"doc":"l4u/l4u_obj","title":"generate_new_l4u_obj","content":"pub fn generate_new_l4u_obj(\n  name: String,\n  initializer: fn() -&gt; Env,\n) -&gt; L4uObj\n\nSynonyms:\nl4u/l4u_obj.generate_new_l4u_obj\nl4u/l4u_obj generate_new_l4u_obj","url":"l4u/l4u_obj.html#generate_new_l4u_obj"},{"doc":"l4u/l4u_obj","title":"process_get_env","content":"pub fn process_get_env(pid: Pid) -&gt; Env\n Name of this L4uObj.\n PID of the process where EVAL is executed.\n Get the current environment of the L4uObj. \n Evaluate the given list of s-expressions in the environment\n Read the given string and return the list of s-expressions.\n Print the given s-expression and return the string representation.\n\nSynonyms:\nl4u/l4u_obj.process_get_env\nl4u/l4u_obj process_get_env","url":"l4u/l4u_obj.html#process_get_env"},{"doc":"l4u/l4u_obj","title":"l4u/l4u_obj","content":"","url":"l4u/l4u_obj.html"},{"doc":"l4u/bif_std","title":"bif_std_def","content":"pub fn bif_std_def() -&gt; List(#(String, Expr))\n\nSynonyms:\nl4u/bif_std.bif_std_def\nl4u/bif_std bif_std_def","url":"l4u/bif_std.html#bif_std_def"},{"doc":"l4u/bif_std","title":"l4u/bif_std","content":"","url":"l4u/bif_std.html"},{"doc":"l4u/bif_datetime","title":"bif_datetime_def","content":"pub fn bif_datetime_def() -&gt; List(#(String, Expr))\n\nSynonyms:\nl4u/bif_datetime.bif_datetime_def\nl4u/bif_datetime bif_datetime_def","url":"l4u/bif_datetime.html#bif_datetime_def"},{"doc":"l4u/bif_datetime","title":"datetime_format","content":"pub fn datetime_format(timestamp: Int, format: String) -&gt; String\n\nSynonyms:\nl4u/bif_datetime.datetime_format\nl4u/bif_datetime datetime_format","url":"l4u/bif_datetime.html#datetime_format"},{"doc":"l4u/bif_datetime","title":"epoch","content":"pub fn epoch() -&gt; Int\n\nSynonyms:\nl4u/bif_datetime.epoch\nl4u/bif_datetime epoch","url":"l4u/bif_datetime.html#epoch"},{"doc":"l4u/bif_datetime","title":"start","content":"pub fn start() -&gt; Nil\n\nSynonyms:\nl4u/bif_datetime.start\nl4u/bif_datetime start","url":"l4u/bif_datetime.html#start"},{"doc":"l4u/bif_datetime","title":"l4u/bif_datetime","content":"","url":"l4u/bif_datetime.html"},{"doc":"l4u/bbmustache_js","title":"Argument","content":"pub type Argument =\n  bbmustache.Argument\n\n\nSynonyms:\nl4u/bbmustache_js.Argument\nl4u/bbmustache_js Argument","url":"l4u/bbmustache_js.html#Argument"},{"doc":"l4u/bbmustache_js","title":"MustacheTemplate","content":"pub type MustacheTemplate =\n  bbmustache.Template\n\n\nSynonyms:\nl4u/bbmustache_js.MustacheTemplate\nl4u/bbmustache_js MustacheTemplate","url":"l4u/bbmustache_js.html#MustacheTemplate"},{"doc":"l4u/bbmustache_js","title":"compile","content":"pub fn compile(src: String) -&gt; Template\n\nSynonyms:\nl4u/bbmustache_js.compile\nl4u/bbmustache_js compile","url":"l4u/bbmustache_js.html#compile"},{"doc":"l4u/bbmustache_js","title":"render","content":"pub fn render(\n  template: Template,\n  table: List(#(String, Argument)),\n) -&gt; String\n\nSynonyms:\nl4u/bbmustache_js.render\nl4u/bbmustache_js render","url":"l4u/bbmustache_js.html#render"},{"doc":"l4u/bbmustache_js","title":"string","content":"pub fn string(arg: String) -&gt; Argument\n\nSynonyms:\nl4u/bbmustache_js.string\nl4u/bbmustache_js string","url":"l4u/bbmustache_js.html#string"},{"doc":"l4u/bbmustache_js","title":"l4u/bbmustache_js","content":"","url":"l4u/bbmustache_js.html"},{"doc":"l4u/bif_template","title":"bif_template_def","content":"pub fn bif_template_def() -&gt; List(#(String, Expr))\n\nSynonyms:\nl4u/bif_template.bif_template_def\nl4u/bif_template bif_template_def","url":"l4u/bif_template.html#bif_template_def"},{"doc":"l4u/bif_template","title":"l4u/bif_template","content":"","url":"l4u/bif_template.html"},{"doc":"l4u/l4u","title":"bispform_bindf","content":"pub fn bispform_bindf(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u.bispform_bindf\nl4u/l4u bispform_bindf","url":"l4u/l4u.html#bispform_bindf"},{"doc":"l4u/l4u","title":"bispform_case","content":"pub fn bispform_case(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u.bispform_case\nl4u/l4u bispform_case","url":"l4u/l4u.html#bispform_case"},{"doc":"l4u/l4u","title":"bispform_cond","content":"pub fn bispform_cond(exprs: List(Expr), env: Env) -&gt; Expr\n\nSynonyms:\nl4u/l4u.bispform_cond\nl4u/l4u bispform_cond","url":"l4u/l4u.html#bispform_cond"},{"doc":"l4u/l4u","title":"generate_l4u_process","content":"pub fn generate_l4u_process(\n  name: String,\n  additional_defs: List(#(String, Expr)),\n) -&gt; #(L4uObj, Expr)\n\nSynonyms:\nl4u/l4u.generate_l4u_process\nl4u/l4u generate_l4u_process","url":"l4u/l4u.html#generate_l4u_process"},{"doc":"l4u/l4u","title":"l4u_add_defs","content":"pub fn l4u_add_defs(\n  l4u: L4uObj,\n  defs: List(#(String, Expr)),\n) -&gt; Result(Expr, a)\n\nSynonyms:\nl4u/l4u.l4u_add_defs\nl4u/l4u l4u_add_defs","url":"l4u/l4u.html#l4u_add_defs"},{"doc":"l4u/l4u","title":"l4u_eval","content":"pub fn l4u_eval(l4u: L4uObj, exprs: List(Expr)) -&gt; Expr\n\nSynonyms:\nl4u/l4u.l4u_eval\nl4u/l4u l4u_eval","url":"l4u/l4u.html#l4u_eval"},{"doc":"l4u/l4u","title":"l4u_get_main_process","content":"pub fn l4u_get_main_process() -&gt; L4uObj\n\nSynonyms:\nl4u/l4u.l4u_get_main_process\nl4u/l4u l4u_get_main_process","url":"l4u/l4u.html#l4u_get_main_process"},{"doc":"l4u/l4u","title":"l4u_get_process","content":"pub fn l4u_get_process(name: String) -&gt; Result(L4uObj, String)\n\nSynonyms:\nl4u/l4u.l4u_get_process\nl4u/l4u l4u_get_process","url":"l4u/l4u.html#l4u_get_process"},{"doc":"l4u/l4u","title":"l4u_read_eval","content":"pub fn l4u_read_eval(\n  l4u: L4uObj,\n  src: String,\n) -&gt; Result(Expr, String)\n\nSynonyms:\nl4u/l4u.l4u_read_eval\nl4u/l4u l4u_read_eval","url":"l4u/l4u.html#l4u_read_eval"},{"doc":"l4u/l4u","title":"l4u_rep","content":"pub fn l4u_rep(src: String, l4u: L4uObj) -&gt; Result(Expr, String)\n\nSynonyms:\nl4u/l4u.l4u_rep\nl4u/l4u l4u_rep","url":"l4u/l4u.html#l4u_rep"},{"doc":"l4u/l4u","title":"l4u_rep_native","content":"pub fn l4u_rep_native(src: String, l4u: L4uObj) -&gt; a\n\nSynonyms:\nl4u/l4u.l4u_rep_native\nl4u/l4u l4u_rep_native","url":"l4u/l4u.html#l4u_rep_native"},{"doc":"l4u/l4u","title":"l4u_rep_str","content":"pub fn l4u_rep_str(src: String, l4u: L4uObj) -&gt; String\n\nSynonyms:\nl4u/l4u.l4u_rep_str\nl4u/l4u l4u_rep_str","url":"l4u/l4u.html#l4u_rep_str"},{"doc":"l4u/l4u","title":"l4u_repl","content":"pub fn l4u_repl(l4u: L4uObj, prompt: String) -&gt; String\n\nSynonyms:\nl4u/l4u.l4u_repl\nl4u/l4u l4u_repl","url":"l4u/l4u.html#l4u_repl"},{"doc":"l4u/l4u","title":"main","content":"pub fn main() -&gt; String\n\nSynonyms:\nl4u/l4u.main\nl4u/l4u main","url":"l4u/l4u.html#main"},{"doc":"l4u/l4u","title":"main_l4u","content":"pub fn main_l4u() -&gt; L4uObj\n\nSynonyms:\nl4u/l4u.main_l4u\nl4u/l4u main_l4u","url":"l4u/l4u.html#main_l4u"},{"doc":"l4u/l4u","title":"make_new_l4u_env","content":"pub fn make_new_l4u_env(\n  additional_defs: List(#(String, Expr)),\n  additional_files: List(String),\n) -&gt; Env\n\nSynonyms:\nl4u/l4u.make_new_l4u_env\nl4u/l4u make_new_l4u_env","url":"l4u/l4u.html#make_new_l4u_env"},{"doc":"l4u/l4u","title":"start_and_generate_main_l4u","content":"pub fn start_and_generate_main_l4u(\n  additional_defs: List(#(String, Expr)),\n) -&gt; L4uObj\n Initialize to generate a main L4U lisp process\nSynonyms:\nl4u/l4u.start_and_generate_main_l4u\nl4u/l4u start_and_generate_main_l4u","url":"l4u/l4u.html#start_and_generate_main_l4u"},{"doc":"l4u/l4u","title":"start_with_defs","content":"pub fn start_with_defs(defs: List(#(String, Expr))) -&gt; String\n\nSynonyms:\nl4u/l4u.start_with_defs\nl4u/l4u start_with_defs","url":"l4u/l4u.html#start_with_defs"},{"doc":"l4u/l4u","title":"l4u/l4u","content":"","url":"l4u/l4u.html"},{"doc":"examples/l4u/test_l4u","title":"main","content":"pub fn main() -&gt; String\n\nSynonyms:\nexamples/l4u/test_l4u.main\nexamples/l4u/test_l4u main","url":"examples/l4u/test_l4u.html#main"},{"doc":"examples/l4u/test_l4u","title":"examples/l4u/test_l4u","content":"","url":"examples/l4u/test_l4u.html"},{"doc":"kirala_l4u","title":"l4u_eval_to_native","content":"pub fn l4u_eval_to_native(l4uobj: L4uObj, src: String) -&gt; a\n\nSynonyms:\nkirala_l4u.l4u_eval_to_native\nkirala_l4u l4u_eval_to_native","url":"kirala_l4u.html#l4u_eval_to_native"},{"doc":"kirala_l4u","title":"l4u_eval_to_str","content":"pub fn l4u_eval_to_str(l4uobj: L4uObj, src: String) -&gt; String\n\nSynonyms:\nkirala_l4u.l4u_eval_to_str\nkirala_l4u l4u_eval_to_str","url":"kirala_l4u.html#l4u_eval_to_str"},{"doc":"kirala_l4u","title":"main","content":"pub fn main() -&gt; String\n\nSynonyms:\nkirala_l4u.main\nkirala_l4u main","url":"kirala_l4u.html#main"},{"doc":"kirala_l4u","title":"start_and_generate_main_l4u","content":"pub fn start_and_generate_main_l4u(\n  additional_defs: List(#(String, Expr)),\n) -&gt; L4uObj\n\nSynonyms:\nkirala_l4u.start_and_generate_main_l4u\nkirala_l4u start_and_generate_main_l4u","url":"kirala_l4u.html#start_and_generate_main_l4u"},{"doc":"kirala_l4u","title":"start_main_l4u","content":"pub fn start_main_l4u() -&gt; L4uObj\n\nSynonyms:\nkirala_l4u.start_main_l4u\nkirala_l4u start_main_l4u","url":"kirala_l4u.html#start_main_l4u"},{"doc":"kirala_l4u","title":"kirala_l4u","content":"","url":"kirala_l4u.html"}]);